package weipinshang_api

import (
	"log"
	"testing"
)

func TestWeiPinShangClient_GetManyPostage(t *testing.T) {
	type fields struct {
		Host        string
		ChannelType string
		Key         string
	}
	//type args struct {
	//	ip string
	//}
	tests := []struct {
		name    string
		fields  fields
		args    GetManyPostageReq
		wantRes *GetManyPostageRes
		wantErr bool
	}{
		{
			name: "test1",
			fields: fields{
				Host:        "https://uat.api.weipinshang.net/",
				ChannelType: "AILEHUI",
				Key:         "f654ea5bde7635c3f46191191e5c4c8e",
			},
			args: GetManyPostageReq{
				GoodsInfo: "[{\"goodsId\":\"WPS592_00019\",\"goodSpecId\":\"WPS592_1105165115160944\",\"num\":1},{\"goodsId\":\"WPS505_00007\",\"goodSpecId\":\"WPS505_1007111249857536\",\"num\":1}]",
				Province:  "广东省",
				Address:   "奥园",
				City:      "广州市",
				County:    "番禺区",
			},
		},
	}
	for _, test := range tests {
		t.Run(test.name, func(t *testing.T) {
			h := &WeiPinShangClient{
				Host:        test.fields.Host,
				ChannelType: test.fields.ChannelType,
				Key:         test.fields.Key,
			}

			gotRes, err := h.GetManyPostage(&test.args)

			log.Println(gotRes, err)

			if (err != nil) != test.wantErr {
				t.Errorf("GetManyPostage() error = %v, wantErr %v", err, test.wantErr)
			}
		})
	}
}

func TestWeiPinShangClient_PreOrder(t *testing.T) {
	type fields struct {
		Host        string
		ChannelType string
		Key         string
	}
	//type args struct {
	//	ip string
	//}
	tests := []struct {
		name    string
		fields  fields
		args    PreOrderReq
		wantRes *PreOrderRes
		wantErr bool
	}{
		{
			name: "test1",
			fields: fields{
				Host:        "https://uat.api.weipinshang.net/",
				ChannelType: "AILEHUI",
				Key:         "f654ea5bde7635c3f46191191e5c4c8e",
			},
			args: PreOrderReq{
				GoodsInfo:         "[{\"goodsId\":\"WPS9_282520\",\"goodSpecId\":\"WPS9_1221183858889276\",\"num\":1}]",
				Province:          "广东省",
				Address:           "奥园",
				City:              "广州市",
				Area:              "番禺区",
				ConsigneePhone:    "15375390426",
				ConsigneeContacts: "张三",
				LockCode:          "L1234567890",
				Source:            "AILEHUI",
			},
		},
	}
	for _, test := range tests {
		t.Run(test.name, func(t *testing.T) {
			h := &WeiPinShangClient{
				Host:        test.fields.Host,
				ChannelType: test.fields.ChannelType,
				Key:         test.fields.Key,
			}

			gotRes, err := h.PreOrder(&test.args)

			log.Println(gotRes, err)

			if (err != nil) != test.wantErr {
				t.Errorf("GetManyPostage() error = %v, wantErr %v", err, test.wantErr)
			}
		})
	}
}

func TestWeiPinShangClient_CreateOrder(t *testing.T) {
	type fields struct {
		Host        string
		ChannelType string
		Key         string
	}
	//type args struct {
	//	ip string
	//}
	tests := []struct {
		name    string
		fields  fields
		args    CreateOrderReq
		wantRes *CreateOrderRes
		wantErr bool
	}{
		{
			name: "test1",
			fields: fields{
				Host:        "https://uat.api.weipinshang.net/",
				ChannelType: "AILEHUI",
				Key:         "f654ea5bde7635c3f46191191e5c4c8e",
			},
			args: CreateOrderReq{
				LockCode: "L1234567890",
				OrderNo:  "10000000000",
			},
		},
	}
	for _, test := range tests {
		t.Run(test.name, func(t *testing.T) {
			h := &WeiPinShangClient{
				Host:        test.fields.Host,
				ChannelType: test.fields.ChannelType,
				Key:         test.fields.Key,
			}

			gotRes, err := h.CreateOrder(&test.args)

			log.Println(gotRes, err)

			if (err != nil) != test.wantErr {
				t.Errorf("GetManyPostage() error = %v, wantErr %v", err, test.wantErr)
			}
		})
	}
}

func TestWeiPinShangClient_GetOrderInfoByItemNO(t *testing.T) {
	type fields struct {
		Host        string
		ChannelType string
		Key         string
	}
	type args struct {
		mcOrderNo string
	}
	tests := []struct {
		name    string
		fields  fields
		args    args
		wantRes *GetOrderInfoByItemNORes
		wantErr bool
	}{
		{
			name: "test1",
			fields: fields{
				Host:        "https://uat.api.weipinshang.net/",
				ChannelType: "AILEHUI",
				Key:         "f654ea5bde7635c3f46191191e5c4c8e",
			},
			args: args{
				mcOrderNo: "mc20250527174640537475",
			},
		},
	}
	for _, test := range tests {
		t.Run(test.name, func(t *testing.T) {
			h := &WeiPinShangClient{
				Host:        test.fields.Host,
				ChannelType: test.fields.ChannelType,
				Key:         test.fields.Key,
			}

			gotRes, err := h.GetOrderInfoByItemNO(test.args.mcOrderNo)

			log.Println(gotRes, err)

			if (err != nil) != test.wantErr {
				t.Errorf("GetManyPostage() error = %v, wantErr %v", err, test.wantErr)
			}
		})
	}
}

func TestWeiPinShangClient_GetOrderInfoByThirdNO(t *testing.T) {
	type fields struct {
		Host        string
		ChannelType string
		Key         string
	}
	type args struct {
		orderNo string
	}
	tests := []struct {
		name    string
		fields  fields
		args    args
		wantRes *GetOrderInfoByThirdNORes
		wantErr bool
	}{
		{
			name: "test1",
			fields: fields{
				Host:        "https://uat.api.weipinshang.net/",
				ChannelType: "AILEHUI",
				Key:         "f654ea5bde7635c3f46191191e5c4c8e",
			},
			args: args{
				orderNo: "10000000000",
			},
		},
	}
	for _, test := range tests {
		t.Run(test.name, func(t *testing.T) {
			h := &WeiPinShangClient{
				Host:        test.fields.Host,
				ChannelType: test.fields.ChannelType,
				Key:         test.fields.Key,
			}

			gotRes, err := h.GetOrderInfoByThirdNO(test.args.orderNo)

			log.Println(gotRes, err)

			if (err != nil) != test.wantErr {
				t.Errorf("GetManyPostage() error = %v, wantErr %v", err, test.wantErr)
			}
		})
	}
}
